c compile with f77 -W -N114 -f -C test_vt_md.f; /bin/mv a.out test_vt_md.x

c this file takes in Manuel Lopex-Puertas files, and adds info to them so that
c they are in the same format as files required for Dave Edwards GENLN2
c The files can then be read in by subroutine  ReadGENLN2_NLTE_Profile

c same as convert.f except we try to compute the QV partition function using
c equation 17 of the JQSRT paper by Edwards, Lopez-Puertas, Gamache
c (v 59, no 3, pg 426 , 1998)

      IMPLICIT NONE 

c for QV
      CHARACTER*80 caFname1
      REAL raaVT(10,70,200)                      !!!ISO,band,T
      REAL raaBand(10,70)                        !!!ISO,band
      REAL raaQV(10,200)                         !!!the QVibPartFcns we compute
      REAL raaQV_DE(10,200)                      !!!the QVibPartFcns Edward has
      INTEGER iaQISO(10),iNV

c local vars
      INTEGER iI,iJ,iK

      DO iI = 1,10
        iaQISO(iI) = 0
        DO iJ = 1,70
          raaBand(iI,iJ) = -10.0
          DO iK = 1,200
            raaVT(iI,iJ,iK) = -10.0
            END DO
          END DO
        END DO
      DO iI = 1,10
        DO iK = 1,200
          raaQV(iI,iK) = 1.0    !!!accounts for the ground state!
          END DO
        END DO

      caFname1 = '../FOURTH_TEST/DEdwardsDATA/NEW/vt_md_co2.dat'
      CALL Read_vt_md_File(caFName1,iNV,raaVT,raaBand,iaQISO,raaQV_DE)
      CALL ComputeQV(iNV,raaVT,raaBand,iaQISO,raaQV,raaQV_DE)
      DO iI = 1,4
        DO iJ = 1,iNV
          print *,iI,raaQV(iI,iJ),raaQV_DE(iI,iJ),raaQV(iI,iJ)/raaQV_DE(iI,iJ)
          END DO
        END DO

      END

************************************************************************
c this function computes the degeneracy
      INTEGER FUNCTION find_degeneracy(iISO,iHIT_ID,rX,
     $  iaDegenBand,iaaDegen_HIT_ID,raaDegen_BandCenter,iaaDegen_number)

      IMPLICIT NONE

c input vars
      INTEGER iaDegenBand(10),iaaDegen_HIT_ID(10,50),iaaDegen_number(10,50)
      REAL raaDegen_Bandcenter(10,50),rX
      INTEGER iISO,iHIT_ID

c local vars 
      INTEGER iI,iJ,iAns,iFound

      iAns = 1    !default degen

      IF  ((iHIT_ID .GT. 0) .AND. (rX  .LT. 0)) THEN
        !!need to search on HITRAN iDs
        iFound = -1
        iJ = 1
 40     CONTINUE
        IF (iaaDegen_HIT_ID(iISO,iJ) .EQ. iHIT_ID) THEN
          iAns = iaaDegen_number(iISO,iJ)
          iFound = +1
          print *,'set     degen',iISO,iaaDegen_HIT_ID(iISO,iJ),
     $            raaDegen_BandCenter(iISO,iJ),iAns
          GOTO 50
        ELSEIF (iJ .LT. iaDegenBand(iISO)) THEN
          iJ = iJ + 1
          GOTO 40
          END IF
        END IF

      IF  ((iHIT_ID .LT. 0) .AND. (rX  .GT. 0)) THEN
        !!need to search on band centers
        iFound = -1
        iJ = 1
 45     CONTINUE
        IF (abs(raaDegen_Bandcenter(iISO,iJ)-rX) .LE. 0.1) THEN
          iAns = iaaDegen_number(iISO,iJ)
          iFound = +1
          print *,'set     degen',iISO,iaaDegen_HIT_ID(iISO,iJ),
     $            raaDegen_BandCenter(iISO,iJ),iAns
          GOTO 50
        ELSEIF (iJ .LT. iaDegenBand(iISO)) THEN
          iJ = iJ + 1
          GOTO 45
          END IF
        END IF

 50   CONTINUE

      IF (iFound .LT. 0) THEN
        print *,'default degen',iISO,iHIT_ID,rX,1
        END IF
      find_degeneracy = iAns

      RETURN
      END

c************************************************************************
c this function loads in the degeneracy file
      SUBROUTINE load_co2_file(
     $  iaDegenBand,iaaDegen_HIT_ID,raaDegen_BandCenter,iaaDegen_number)

      IMPLICIT NONE

c output vars
      INTEGER iaDegenBand(10),iaaDegen_HIT_ID(10,50),iaaDegen_number(10,50)
      REAL raaDegen_Bandcenter(10,50)

c local vars
      INTEGER iI,iJ,iK,iL,iIOUN,iCount,iISO,iHITRANID,iDegeneracy,iErr
      REAL rBandCenter
      CHARACTER*80 cafname,caStr

      DO iI = 1,10
        iaDegenBand(iI) = 0
        END DO
      DO iI = 1,10
        DO iJ = 1,50
          iaaDegen_HIT_ID(iI,iJ) = 0
          iaaDegen_number(iI,iJ) = 0
          raaDegen_BandCenter(iI,iJ) = 1.0e10
          END DO
        END DO

      caFname = 'co2_degeneracies.txt'

      iIOun = 11
      OPEN(UNIT=iIOun,FILE=caFName,FORM='formatted',STATUS='OLD', 
     $     IOSTAT=iErr)  
      IF (iErr .NE. 0) THEN  
        print *, 'error reading co2-degeneracies ',iErr,caFName
        stop
        END IF  
      
 40   CONTINUE
      READ (iIOUN,10,err=50) caStr
      IF (caStr(1:1) .EQ. '!') THEN
        GOTO 40
      ELSE
        READ(caStr,*)  iCount,iISO,iHITRANID,rBandCenter,iDegeneracy
        iaDegenBand(iISO) = iaDegenBand(iISO) + 1
        iaaDegen_HIT_ID(iISO,iaDegenBand(iISO)) = iHITRANID
        raaDegen_BandCenter(iISO,iaDegenBand(iISO)) = rBandCenter
        iaaDegen_number(iISO,iaDegenBand(iISO)) = iDegeneracy
        GOTO 40
        END IF

 50   CONTINUE
      CLOSE(iIOUN)

 10   FORMAT(A80)

      print *,'read degeneracy table '
      DO iI = 1,10
        IF (iaDegenBand(ii) .GT. 0) THEN 
          print *,iI,iaDegenBand(ii)
          END IF
        END DO
      print *,' '

      RETURN
      END

c************************************************************************
c this subroutine computes the QV function according to Edwards, Puertas, 
c Gamache eqn
      SUBROUTINE ComputeQV(iNV,raaVT,raaBand,iaQISO,raaQV)

      IMPLICIT NONE

c input vars
      INTEGER iaQISO(10),iNV
      REAL raaVT(10,70,200)                      !!!ISO,band,T
      REAL raaBand(10,70)                        !!!ISO,band
c output vars
      REAL raaQV(10,200)                         !!!the QVibPartFcns

c local vars
      INTEGER iI,iJ,iK
      REAL c2,rX,iD
      INTEGER iaDegenBand(10),iaaDegen_HIT_ID(10,50),iaaDegen_number(10,50)
      REAL raaDegen_Bandcenter(10,50)
      INTEGER find_degeneracy

      c2 = 1.4387863           !!!second radiaive constant; see c1,c2 in kCARTA

      CALL load_co2_file(
     $  iaDegenBand,iaaDegen_HIT_ID,raaDegen_BandCenter,iaaDegen_number)

      DO iI = 1,10
        IF (iaQISO(iI) .GT. 0) THEN
          print *,' isotope, num of bands = ',iI,iaQISO(iI)
          DO iJ = 1,iaQISO(iI)
            iD = 1
            iD = find_degeneracy(iI,-1,raaBand(iI,iJ),
     $  iaDegenBand,iaaDegen_HIT_ID,raaDegen_BandCenter,iaaDegen_number)
            DO iK = 1,iNV
              rX = c2*raaBand(iI,iJ)/raaVT(iI,iJ,iK)
              raaQV(iI,iK) = raaQV(iI,iK) + iD*exp(-rX)
              END DO 
            END DO
          END IF
        END DO


      RETURN
      END

c************************************************************************
c this subroutine reads in the vib temps
c in the format that GENLN2 and kCARTA like 
      SUBROUTINE Read_vt_md_File(caFName1,
     $                           iNV,raaVT,raaBand,iaQISO,raaQV_DE)
 
      IMPLICIT NONE 

c input params
      CHARACTER*80 caFname1
c output params for QV
      REAL raaVT(10,70,200)                      !!!ISO,band,T
      REAL raaBand(10,70)                        !!!ISO,band
      INTEGER iaQISO(10),iNV
      REAL raaQV_DE(10,200)                      !!!the QVibPartFcns from file

c local vars 
      CHARACTER*3 ca3
      CHARACTER*80 caStr
      INTEGER iModel,iNumBands,iIOUN,iErr,iI,iJ,iK
      INTEGER iDummy1,iDummyGasID,iDummyISO
      INTEGER iGasesInFile,iNumVibLevels,iGasID,iVibPF,iA,iB,iC,iD,iLocalIso
      REAL raPressure(200),raKinetic(200),rX,raVibTemp(200)

      iIOUN = 10
      OPEN(UNIT=iIOun,FILE=caFName1,FORM='formatted',STATUS='OLD',  
     $     IOSTAT=iErr)   
      IF (iErr .NE. 0) THEN   
        print *, 'error reading VibTemp profile ',iErr,caFName1
        stop
        END IF   
 
 555  CONTINUE 
      read(iIOUN,123) caStr 
      IF (caStr(1:1) .EQ. '!') THEN 
        !!!these are comments at beginning of file, so skip 
        GOTO 555 
      ELSEIF (caStr(1:3) .EQ. '***') THEN 
        !!!dave edwards calls this FLAG,MODEL,NSET,NGAS,NLEV 
        !!!where FLAG  = *** 
        !!!      MODEL = atmosphere model number for data file 
        !!!      NSET  = NO OF VIBRATIONAL STATE DATA SETS FOR THIS MODEL 
        !!!      NGAS  = NO OF DIFFERENT GASES FOR WHICH THERE ARE T_VIB      
        !!!      NLEV  = NO OF PRESSURE LEVELS FOR THIS MODEL  
        !!! so read in flag, model,nset,ngas,nlev where flag = '***' 
        read(caStr,456) ca3,iModel,iNumBands,iGasesInFile,iNumVibLevels 
        END IF 

      iModel = 1
      iNumBands = 47
      iGasesInFile = 1
      iNumVibLevels = 121

      iNV = iNumVibLevels

      IF (iNumVibLevels .GT. 200) THEN
        print *, 'kCARTA can handle max 200 NLTE levels!'
        Stop
        END IF

      READ(iIOUN,*) iGasID,iVibPF
      print *,iGasID,iVibPF

      IF (iVibPF .GT. 10) THEN
        print *, 'kCARTA can only handle 10 Vib part fcns!!'
        Stop
        END IF

      !!!read the presssure levels 
      read(iIOUN,*) (raPressure(iI),iI=1,iNumVibLevels)   !!! in mb 

      !!! read the kinetic temperatures 
      read(iIOUN,*) iDummy1 
      read(iIOUN,*) (raKinetic(iI),iI=1,iNumVibLevels)   !!!LTE temp

      !!!read in the QTIPS_VIB modifiers 
      !!!dummy string that says "!QV   Vibrational Partition functions" 
      read(iIOUN,123) caStr       
      DO iJ = 1,iVibPF
        read(iIOUN,*) iDummyGasID,iDummyISO 
        read(iIOUN,*) (raaQV_DE(iJ,iI),iI=1,iNumVibLevels)
        END DO

      !!! read the NLTE temperatures 
      !!!dummy string that says "!TV   Vibrational Temperatures" 
      read(iIOUN,123) caStr       
      DO iJ = 1,iNumBands
        read(iIOUN,*) iA,iB,iC,iD,rX
        read(iIOUN,*) (raVibTemp(iK),iK=1,iNumVibLevels)
        !!! store the info in matrices for QV computation
        IF (iB .NE. 2) THEN
          print *,'require gasID == 2'
          stop
          END IF
        iLocalIso = iC
        iaQISO(iLocalIso) = iaQISO(iLocalIso) + 1
        raaBand(iLocalIso,iaQISO(iLocalIso)) = rX
        DO iK = 1,iNV
          raaVT(iLocalIso,iaQISO(iLocalIso),iK) = raVibTemp(iK)
          END DO
        END DO

      CLOSE(iIOUN)

 123  FORMAT(A80)
 456  FORMAT(A3,'   ',4(I3,' ')) 
 789  FORMAT(A1,'   ',I3)

      RETURN 
      END

c************************************************************************
