function [data0,dataSol] = driver_compare_vmr_vs_solzen(iProf)

%{
>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set001_100/Sergio_vt_profs_1_100/vts | wc -l       100 profiles * 3 co2 amounts x 13 solang
3900
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set001_100/Sergio_vt_profs_1_100/pt | wc -l        100 profiles
100
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set001_100/Sergio_vt_profs_1_100/vmr | wc -l       100 profles + 2 extra CO2 amounts for profile 1
102

%%%%%%%%%%%%%%%%%%%%%%%%%

[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set101_200/Sergio_vt_profs_101_200/vts | wc -l      100 profiles * 3 co2 amounts x 13 solang
3900
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set101_200/Sergio_vt_profs_101_200/pt | wc -l       001-100,101-200 profiles
200
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set101_200/Sergio_vt_profs_101_200/vmr | wc -l      001-100,101-200 profiles plus profile 001 has two additional CO2
202

%%%%%%%%%%%%%%%%%%%%%%%%%

[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/vts/ | wc -l         149 profiles x 3 co2 amounts x 13 solang
5811

[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/pt_vmrs/ | wc -l     HMMM?????
4889
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/pt_vmrs/pt* | wc -l            
349
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/pt_vmrs/vmr* | wc -l            
4540

[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/pt_vmrs/vmr1_s*  | wc -l
16
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/pt_vmrs/vmr100_s*  | wc -l
13
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/pt_vmrs/vmr200_s*  | wc -l
13
[sergio@taki-usr2 NONLTE4_Jan2025]$ ls Set201_349/Sergio_vt_profs_201_349_the_end/pt_vmrs/vmr300_s*  | wc -l
13

From Manuel, Jan 29, 2025, for Set201_349
Here I computed the VTs for the remaining 201 to 349 pT profiles.

I also put in this directory the 349 pT profiles that I used together
with the concentrations (vmr_xxx_syyy files) for the 349*13 cases we
used. I did not want to triplicate those vmr files for the 3 CO2 vmr
profiles. Instead, you can find them the files:

vmr1_s0_co2_1.prf
vmr1_s0_co2_2.prf
vmr1_s0_co2_3.prf

Note that the vmr_xxx_syyy files also contain CO2 vmr profiles, but
they were NOT used. I took the concentrations for all species in the
vmr_xxx_syyy files except CO2 and combined them with each of the 3 CO2
vmr profiles included in the vmr files listed above. So we have the
total of 349*13*3 VT runs.

>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
%}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

addpath /home/sergio/MATLABCODE
x = read_netcdf_lls('MAKE_vtPROF_sSOL_prf_Oct2024/saf_sub300_reg49_plv147_400ppm.nc');

data0 = [];
dataSol = [];

if iProf < 100
  dir0 = 'Set001_100/Sergio_vt_profs_1_100/';
elseif iProf < 200
  dir0 = 'Set101_200/Sergio_vt_profs_101_200/';
elseif iProf < 349
  dir0 = 'Set201_349/Sergio_vt_profs_201_349_the_end/';
end

dirX = 'Set201_349/Sergio_vt_profs_201_349_the_end/';

if iProf <= 200
  data0_vmr = read_manuel_vmr([dir0 '/vmr/'],iProf);
  data0_pt  = read_manuel_pt([dir0 '/pt/'],iProf);
else
  data0_vmr = read_manuel_vmr([dir0 '/pt_vmrs/'],iProf);
  data0_pt  = read_manuel_pt([dir0 '/pt_vmrs/'],iProf);
end
data0.vmr = data0_vmr;
data0.pt  = data0_pt;

iaSol = [00 15 30 40 50 60 70 80 85 90 95 100 120];

disp(' ')
for iSol = 1 : length(iaSol)
  dir0 = 'Set201_349/Sergio_vt_profs_201_349_the_end/';
  dataZ_vmr = read_manuel_vmr_001_359_solang_co2([dir0 '/pt_vmrs/'],iProf,iaSol(iSol),0);  %% use incorrect CO2 (388 ppmv) instead of 1,2,3 = 370,415,460 ppmv
  dataSol{iSol} = dataZ_vmr;
end
%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1); clf;
iG = 1;
semilogx(data0.vmr.vmr(iG,:),data0.vmr.Z,'kx-','linewidth',2)
hold on
semilogy(x.h2o(:,iProf),x.altitude(:,iProf)/1000,'g.-','linewidth',2)
for ii = 1 : length(iaSol)
  semilogx(dataSol{ii}.vmr(iG,:),dataSol{ii}.Z)
end
title(['Prof ' num2str(iProf,'%03i') ' WV'])
xlabel('PPMV'); ylabel('Z [km]');
hold off
ax = axis; ax(1) = min(data0.vmr.vmr(iG,:)); ax(2) = max(data0.vmr.vmr(iG,:)); line([ax(1) ax(2)],[82 82],'color','k'); text(ax(1)*1.1,83,'82 km');
legend('Set001-200','Chris H','Different solzen','location','best','fontsize',10);

figure(2); clf;
iG = 2;
semilogx(data0.vmr.vmr(iG,:),data0.vmr.Z,'kx-','linewidth',2)
hold on
semilogy(x.co2(:,iProf),x.altitude(:,iProf)/1000,'g.-','linewidth',2)
for ii = 1 : length(iaSol)
  semilogx(dataSol{ii}.vmr(iG,:),dataSol{ii}.Z)
end
title(['Prof ' num2str(iProf,'%03i') ' CO2'])
xlabel('PPMV'); ylabel('Z [km]');
hold off
%ax = axis; line([ax(1) ax(2)],[82 82],'color','k'); % text(ax(1)*1.1,83,'82 km');
ax = axis; ax(1) = min(data0.vmr.vmr(iG,:)); ax(2) = max(data0.vmr.vmr(iG,:)); line([ax(1) ax(2)],[82 82],'color','k'); text(ax(1)*1.1,83,'82 km');
legend('Set001-200','Chris H','Different solzen','location','best','fontsize',10);

figure(3); clf;
iG = 3;
semilogx(data0.vmr.vmr(iG,:),data0.vmr.Z,'kx-','linewidth',2)
hold on
semilogy(x.ozone(:,iProf),x.altitude(:,iProf)/1000,'g.-','linewidth',2)
for ii = 1 : length(iaSol)
  semilogx(dataSol{ii}.vmr(iG,:),dataSol{ii}.Z)
end
title(['Prof ' num2str(iProf,'%03i') ' O3'])
xlabel('PPMV'); ylabel('Z [km]');
hold off
%ax = axis; line([ax(1) ax(2)],[82 82],'color','k'); % text(ax(1)*1.1,83,'82 km');
ax = axis; ax(1) = min(data0.vmr.vmr(iG,:)); ax(2) = max(data0.vmr.vmr(iG,:)); line([ax(1) ax(2)],[82 82],'color','k'); text(ax(1)*1.1,83,'82 km');
legend('Set001-200','Chris H','Different solzen','location','best','fontsize',10);

figure(4); clf
plot(data0.pt.T,data0.pt.Z,'kx-','linewidth',2)
hold on
plot(x.temperature(:,iProf),x.altitude(:,iProf)/1000,'g.-','linewidth',2)
legend('Set001-200','Chris H','location','best','fontsize',10);
ax = axis; xlim([ax(1) 400])
title(['Prof ' num2str(iProf,'%03i') ' TZ'])

%%%%%%%%%%%%%%%%%%%%%%%%%
iShowDiff = +1;
iShowDiff = input('Show diffs between Chris and Manuel (+1/default yes/ -1 no) : ');
if length(iShowDiff) == []
  iShowDiff = 1;
end

if iShowDiff > 0
  ii = 1;

  ZZZ = 0:1:120;

  umbcT = interp1(x.altitude(:,iProf)/1000,x.temperature(:,iProf),ZZZ,[],'extrap');
  mlpT  = interp1(data0.pt.Z,data0.pt.T,ZZZ,[],'extrap');
  figure(4); clf; plot(umbcT-mlpT,ZZZ);  title(['Prof ' num2str(iProf,'%03i') ' TZ : UMBC-MLP'])
  plotaxis2;
  xlim([-1 +1]*2);

  iG = 1;
  for ii = 1 : 7
    umbcWV = interp1(x.altitude(:,iProf)/1000,x.h2o(:,iProf),ZZZ,[],'extrap');
    mlpWV(ii,:)  = interp1(dataSol{ii}.Z,dataSol{ii}.vmr(iG,:),ZZZ,[],'extrap');
  end
  figure(1); clf; plot(mlpWV./umbcWV,ZZZ); title(['Prof ' num2str(iProf,'%03i') ' WV : MLP/UMBC'])
  plotaxis2(1);

  iG = 2;
  umbcCO2 = interp1(x.altitude(:,iProf)/1000,x.co2(:,iProf),ZZZ,[],'extrap');
  for ii = 1 : 7
    mlpCO2(ii,:)  = interp1(dataSol{ii}.Z,dataSol{ii}.vmr(iG,:),ZZZ,[],'extrap');
  end
  figure(2); clf; plot(mlpCO2./umbcCO2,ZZZ); title(['Prof ' num2str(iProf,'%03i') ' CO2 : MLP/UMBC'])
  plotaxis2(1);

  iG = 3;
  umbcOZ = interp1(x.altitude(:,iProf)/1000,x.ozone(:,iProf),ZZZ,[],'extrap');
  for ii = 1 : 7
    mlpOZ(ii,:)  = interp1(dataSol{ii}.Z,dataSol{ii}.vmr(iG,:),ZZZ,[],'extrap');
  end
  figure(3); clf; plot(mlpOZ./umbcOZ,ZZZ); title(['Prof ' num2str(iProf,'%03i') ' OZ : MLP/UMBC'])
  plotaxis2(1);

  whos umbc* mlp*
end
